==> flutter_pluggy_connect-0.1.0.tar.gz: lib/src/pluggy_connect.dart <==
import 'dart:convert';

import 'package:flutter/material.dart';
import 'package:flutter_inappwebview/flutter_inappwebview.dart';

import 'connect_webview.dart';
import 'oauth_webview.dart';
import 'utils.dart';

// TODO: Add types and replace Object
typedef OnSuccessCallback = void Function(Object data);
typedef OnErrorCallback = void Function(Object error);
typedef OnEventCallback = void Function(String event, Object metadata);

class PluggyConnect extends StatefulWidget {
  PluggyConnect(
      {Key? key,
      this.url = 'https://connect.pluggy.ai',
      required this.connectToken,
      this.includeSandbox = false,
      this.updateItem,
      this.connectorTypes = const [],
      this.connectorIds = const [],
      this.countries = const [],
      this.language = 'pt',
      this.onSuccess,
      this.onError,
      this.onOpen,
      this.onClose,
      this.onEvent})
      : super(key: key) {
    WidgetsFlutterBinding.ensureInitialized();
    _connectUrl = buildConnectUrl(connectToken, updateItem, connectorIds,
        connectorTypes, countries, includeSandbox, language, url);
  }

  final String url;
  final String connectToken;
  final bool includeSandbox;
  final String? updateItem;
  // TODO: Add types
  final List<String> connectorTypes;
  final List<int> connectorIds;
  // TODO: Add types
  final List<String> countries;
  final String language;
  final OnSuccessCallback? onSuccess;
  final OnErrorCallback? onError;
  final VoidCallback? onOpen;
  final VoidCallback? onClose;
  final OnEventCallback? onEvent;
  late final String _connectUrl;

  @override
  State<StatefulWidget> createState() => _PluggyConnectState();
}

class _PluggyConnectState extends State<PluggyConnect> {
  String? _currentEvent;
  String? _oauthUrl;
  bool _isWaitingPluggyResponse = false;

  _handleConnectUrlUpdate(String query) {
    final queryParams = Uri.splitQueryString(query.replaceFirst('?', ''));
    final events = queryParams['events'];
    final itemId = queryParams['item_id'];
    final itemStatus = queryParams['item_status'];
    final executionStatus = queryParams['execution_status'];
    final error = queryParams['error'];
    final eventType = events?.split(',').last;

    // skip if there is no new events
    if (eventType == null || eventType == _currentEvent) {
      return;
    }

    // new event, handle it
    setState(() {
      _currentEvent = eventType;
    });

    // event item data
    final itemData = {
      'id': itemId,
      'status': itemStatus,
      'executionStatus': executionStatus,
    };

    if (isConnectEventType(eventType)) {
      widget.onEvent?.call(eventType, {'timestamp': DateTime.now()});
      return;
    }

    switch (eventType) {
      case 'OPEN':
        widget.onOpen?.call();
        break;
      case 'CLOSE':
        widget.onClose?.call();
        break;
      case 'ERROR':
        widget.onError?.call({
          'message': error ?? '',
          ...(itemId != null
              ? {
                  'data': {
                    'item': itemData,
                  }
                }
              : {})
        });
        break;
      case 'SUCCESS':
        widget.onSuccess?.call({'item': itemData});
        break;
    }
  }

  _handleOnOauthOpen(String oauthUrl) {
    setState(() {
      _oauthUrl = oauthUrl;
    });
  }

  _handleOauthCallback() {
    setState(() {
      _oauthUrl = null;
      _isWaitingPluggyResponse = false;
    });
  }

  _onWaitingPluggyResponseChange(bool value) {
    setState(() {
      _isWaitingPluggyResponse = value;
    });
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
        backgroundColor: Colors.white,
        body: _oauthUrl == null
            ? ConnectWebView(
                url: widget._connectUrl,
                onLocationUpdate: _handleConnectUrlUpdate,
                onOauthOpen: _handleOnOauthOpen,
                visible: _oauthUrl == null || _isWaitingPluggyResponse,
              )
            : OauthWebView(
                url: _oauthUrl as String,
                isWaitingPluggyResponse: _isWaitingPluggyResponse,
                onOauthCallback: _handleOauthCallback,
                onWaitingPluggyResponseChange: _onWaitingPluggyResponseChange,
              ));
  }
}

==> flutter_pluggy_connect-0.2.0.tar.gz: lib/src/pluggy_connect.dart <==
import 'dart:convert';

import 'package:flutter/material.dart';
import 'package:flutter_inappwebview/flutter_inappwebview.dart';

import 'connect_webview.dart';
import 'oauth_webview.dart';
import 'utils.dart';

// TODO: Add types and replace Object
typedef OnSuccessCallback = void Function(dynamic data);
typedef OnErrorCallback = void Function(dynamic error);
typedef OnEventCallback = void Function(String event, dynamic metadata);

class PluggyConnect extends StatefulWidget {
  PluggyConnect(
      {Key? key,
      this.url = 'https://connect.pluggy.ai',
      required this.connectToken,
      this.includeSandbox = false,
      this.updateItem,
      this.connectorTypes = const [],
      this.connectorIds = const [],
      this.countries = const [],
      this.language = 'pt',
      this.onSuccess,
      this.onError,
      this.onOpen,
      this.onClose,
      this.onEvent})
      : super(key: key) {
    WidgetsFlutterBinding.ensureInitialized();
    _connectUrl = buildConnectUrl(connectToken, updateItem, connectorIds,
        connectorTypes, countries, includeSandbox, language, url);
  }

  final String url;
  final String connectToken;
  final bool includeSandbox;
  final String? updateItem;
  // TODO: Add types
  final List<String> connectorTypes;
  final List<int> connectorIds;
  // TODO: Add types
  final List<String> countries;
  final String language;
  final OnSuccessCallback? onSuccess;
  final OnErrorCallback? onError;
  final VoidCallback? onOpen;
  final VoidCallback? onClose;
  final OnEventCallback? onEvent;
  late final String _connectUrl;

  @override
  State<StatefulWidget> createState() => _PluggyConnectState();
}

class _PluggyConnectState extends State<PluggyConnect> {
  String? _currentEvent;
  String? _oauthUrl;
  bool _isWaitingPluggyResponse = false;

  _handleConnectUrlUpdate(String query) {
    final queryParams = Uri.splitQueryString(query.replaceFirst('?', ''));
    final events = queryParams['events'];
    final itemId = queryParams['item_id'];
    final itemStatus = queryParams['item_status'];
    final executionStatus = queryParams['execution_status'];
    final error = queryParams['error'];
    final eventType = events?.split(',').last;

    // skip if there is no new events
    if (eventType == null || eventType == _currentEvent) {
      return;
    }

    // new event, handle it
    setState(() {
      _currentEvent = eventType;
    });

    // event item data
    final itemData = {
      'id': itemId,
      'status': itemStatus,
      'executionStatus': executionStatus,
    };

    if (isConnectEventType(eventType)) {
      widget.onEvent?.call(eventType, {'timestamp': DateTime.now()});
      return;
    }

    switch (eventType) {
      case 'OPEN':
        widget.onOpen?.call();
        break;
      case 'CLOSE':
        widget.onClose?.call();
        break;
      case 'ERROR':
        widget.onError?.call({
          'message': error ?? '',
          ...(itemId != null
              ? {
                  'data': {
                    'item': itemData,
                  }
                }
              : {})
        });
        break;
      case 'SUCCESS':
        widget.onSuccess?.call({'item': itemData});
        break;
    }
  }

  _handleOnOauthOpen(String oauthUrl) {
    setState(() {
      _oauthUrl = oauthUrl;
    });
  }

  _handleOauthCallback() {
    setState(() {
      _oauthUrl = null;
      _isWaitingPluggyResponse = false;
    });
  }

  _onWaitingPluggyResponseChange(bool value) {
    setState(() {
      _isWaitingPluggyResponse = value;
    });
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
        backgroundColor: Colors.white,
        body: _oauthUrl == null
            ? ConnectWebView(
                url: widget._connectUrl,
                onLocationUpdate: _handleConnectUrlUpdate,
                onOauthOpen: _handleOnOauthOpen,
                visible: _oauthUrl == null || _isWaitingPluggyResponse,
              )
            : OauthWebView(
                url: _oauthUrl as String,
                isWaitingPluggyResponse: _isWaitingPluggyResponse,
                onOauthCallback: _handleOauthCallback,
                onWaitingPluggyResponseChange: _onWaitingPluggyResponseChange,
              ));
  }
}
